####################
project-template API
####################

This is an example on how to document the API of your own project.

.. currentmodule:: bayesclass


TAN
===

.. autosummary::
   :toctree: generated/
   :template: class.rst

   TAN

